/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.action;

import javax.swing.*;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.resource.*;
import edu.stanford.smi.protege.ui.*;
import edu.stanford.smi.protege.util.*;

/**
 * Base class for actions that access the current project.  By default instances of this class are disabled
 * if no project is loaded.  To override this call #setEnabled(boolean) in the constructor. 
 *
 * @author    Ray Fergerson <fergerson@smi.stanford.edu>
 */
public abstract class ProjectAction extends StandardAction {

    private static final long serialVersionUID = 6438135888112682135L;

    {
        setEnabled(getProjectManager().getCurrentProject() != null);
    }

    protected ProjectAction(String text) {
        super(text);
    }

    protected ProjectAction(String label, Icon icon) {
        super(label, icon);
    }

    protected ProjectAction(ResourceKey key) {
        super(key);
    }

    protected ProjectAction(ResourceKey key, boolean useLargeIcon) {
        super(key, useLargeIcon);
    }

    protected static ProjectManager getProjectManager() {
        return ProjectManager.getProjectManager();
    }

    protected static Project getProject() {
        return getProjectManager().getCurrentProject();
    }

    protected static KnowledgeBase getKnowledgeBase() {
        Project p = getProject();
        return (p == null) ? null : p.getKnowledgeBase();
    }

    protected static ProjectView getProjectView() {
        return getProjectManager().getCurrentProjectView();
    }

    protected static CommandManager getCommandManager() {
        KnowledgeBase kb = getKnowledgeBase();
        return (kb == null) ? null : kb.getCommandManager();
    }

    protected static JComponent getMainPanel() {
        return getProjectManager().getMainPanel();
    }
}
