/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.model;
//ESCA*JAVA0051

/**
 * Exception thrown when the client calls a method on default knowledge base (directly or indirectly) and passes 
 * in a parameter which is or contains a frame that has been deleted.  For example:
 * 
 * <pre><code>
 * KnowledgeBase kb = ...
 * Slot slot = ...
 * Instance instance = kb.getInstance("foo");
 * kb.deleteFrame(instance);
 * ...
 * i.getOwnSlotValue(slot);     // <-- throws exception
 * </code></pre>
 *
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class DeletedFrameException extends IllegalArgumentException {

    private static final long serialVersionUID = -1201162153303219322L;

    public DeletedFrameException(String s) {
        super(s);
    }
}
