/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.model;

import java.util.*;

/**
 * Value which determines whether a class can have direct instances.  Abstract classes can have no direct instances.
 *
 * @author    Ray Fergerson <fergerson@smi.stanford.edu>
 */
public abstract class RoleConstraint extends AbstractFacetConstraint {
    private static final long serialVersionUID = -8969445861845694716L;
    public static final String ABSTRACT = "Abstract";
    public static final String CONCRETE = "Concrete";
    private static final Collection values;

    static {
        values = new ArrayList();
        values.add(ABSTRACT);
        values.add(CONCRETE);
    }

    public static Collection getValues() {
        return Collections.unmodifiableCollection(values);
    }

    public static boolean isAbstract(String s) {
        return ABSTRACT.equals(s);
    }
}
