/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.model.framestore;

import java.util.logging.Level;
import java.util.logging.Logger;

import edu.stanford.smi.protege.util.Log;
import edu.stanford.smi.protege.util.StringUtilities;

public abstract class AbstractFrameStore implements FrameStore {
    private static Logger log = Log.getLogger(AbstractFrameStore.class);
    private FrameStore delegate;
    private String name;

    protected AbstractFrameStore(String name) {
        if (log.isLoggable(Level.FINE)) {
            log.fine("Constructing abstract frame store name = " + name + " class = " + this.getClass());
            log.fine("FrameStore being constructed = " + this + "/" + this.hashCode());
        }
        this.name = name;
    }

    protected AbstractFrameStore() {
        if (log.isLoggable(Level.FINE)) {
            log.fine("Constructing abstract frame store class = " + this.getClass());
            log.fine("FrameStore being constructed = " + this + "/" + this.hashCode());
        }
        this.name = getClass().getName();
    }

    public void close() {
        delegate = null;
    }

    public String getName() {
        return name;
    }

    public FrameStore getDelegate() {
        return delegate;
    }

    public void setDelegate(FrameStore delegate) {
        if (log.isLoggable(Level.FINE)) {
            log.fine("Setting delegate for " + this + "/" + this.hashCode() 
                    + " delegate = " + delegate + "/" + (delegate == null ? -1 : delegate.hashCode()));
        }
        this.delegate = delegate;
        onSetDelegate();
    }

    public void onSetDelegate() {
        // do nothing
    }

    public String toString() {
        return StringUtilities.getClassName(this);
    }
}