/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.model.framestore.undo;

import java.util.*;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.model.framestore.*;

class DeleteSimpleInstanceCommand extends SimpleCommand {
    private SimpleInstance simpleInstance;
    private FrameID id;
    private Collection directTypes;

    DeleteSimpleInstanceCommand(FrameStore delegate, SimpleInstance simpleInstance) {
        super(delegate);
        this.simpleInstance = simpleInstance;
        this.id = simpleInstance.getFrameID();
        this.directTypes = new ArrayList(simpleInstance.getDirectTypes());
        setDescription("Delete instance " + getText(simpleInstance));
    }

    public Object doIt() {
        getDelegate().deleteSimpleInstance(simpleInstance);
        simpleInstance.markDeleted(true);
        return null;
    }

    public void undoIt() {
        getDelegate().createSimpleInstance(id, directTypes, false);
        simpleInstance.markDeleted(false);
    }
}