/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.plugin;

import java.awt.event.*;

import javax.swing.*;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.util.*;

/**
 * TODO Class Comment
 * 
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class ChangeProjectFormatWizardPage extends ExportWizardPage {
    private static final long serialVersionUID = -3969285986800636849L;
    private Project project;
    private AbstractButton convertProjectButton;
    private BackendExportPlugin plugin;

    public ChangeProjectFormatWizardPage(ExportWizard wizard, BackendExportPlugin plugin, Project project) {
        super("change project format", wizard);
        this.plugin = plugin;
        this.project = project;
        AbstractButton button = createButton("Export Files and Leave Project Unchanged");
        button.setSelected(true);
        convertProjectButton = createButton("Convert Project to this Format");
        ButtonGroup group = new ButtonGroup();
        group.add(button);
        group.add(convertProjectButton);
        setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
        add(button);
        add(convertProjectButton);
        setPageComplete(true);
    }
    
    private AbstractButton createButton(String text) {
        Action action = new AbstractAction(text) {
            private static final long serialVersionUID = -3419514018833124894L;

            public void actionPerformed(ActionEvent event) {
                updateNextPage();
            }
        };
        AbstractButton button = ComponentFactory.createRadioButton(action);
        return button;
    }
    
    public WizardPage getNextPage() {
        WizardPage page;
        if (convertProject()) {
            page = plugin.createExportToNewFormatWizardPage(getExportProjectWizard(), project);
        } else {
            page = plugin.createExportWizardPage(getExportProjectWizard(), project);
        }
        return page;
    }
    
    public void onFinish() {
        ExportWizard wizard = (ExportWizard) getWizard();
        wizard.setExportToNewFormat(convertProject());
    }
    
    private boolean convertProject() {
        return convertProjectButton.isSelected();
    }
}
