/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.plugin;

import java.util.*;

import javax.swing.*;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.util.*;

class PickCreateProjectPluginPage extends WizardPage {
    private static final long serialVersionUID = 7411364041871092526L;
    private SelectableList list;
    private KnowledgeBaseFactory factory;
    
    PickCreateProjectPluginPage(Collection plugins, KnowledgeBaseFactory factory, Wizard wizard) {
        super("pick plugin", wizard);
        this.factory = factory;
        createList(plugins);
        add(new LabeledComponent("Existing Source Type", ComponentFactory.createScrollPane(list)));
        list.setCellRenderer(new CreateProjectPluginRenderer());
    }
    
    private JList createList(Collection plugins) {
        list = ComponentFactory.createSelectableList(null);
        ComponentUtilities.setListValues(list, plugins);
        list.setSelectedIndex(0);
        list.addSelectionListener(new SelectionListener() {
            public void selectionChanged(SelectionEvent event) {
                updateNextPage();
            }
        });
        return list;
    }
    
    public void onFinish() {
        CreateProjectPlugin plugin = (CreateProjectPlugin) list.getSelectedValue();
        plugin.setKnowledgeBaseFactory(factory);
        plugin.setUseExistingSources(true);
        CreateProjectWizard wizard = (CreateProjectWizard) getWizard();
        wizard.setPlugin(plugin);
    }
    
    public WizardPage getNextPage() {
        CreateProjectPlugin plugin = (CreateProjectPlugin) list.getSelectedValue();
        return plugin.createCreateProjectWizardPage((CreateProjectWizard) getWizard(), true);
    }
}

