/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server;

import java.io.Serializable;
import java.util.UUID;


public class Session implements RemoteSession, Serializable {
    private static final long serialVersionUID = -7027997614420432217L;

    private static int nextPrettyId = 0;
    
    private int prettyId;
    private UUID id;
    private boolean allowDelegation;
    
    private String userName;
    private String delegateUserName;
    
    private String userIpAddress;
    private long startTime;
    
    public Session(String userName, String userIpAddress) {
        this(userName, userIpAddress, false);
    }

    public Session(String userName, String userIpAddress, boolean allowDelegation) {
        this.prettyId  = nextPrettyId++;
        this.id = UUID.randomUUID();
        this.allowDelegation = allowDelegation;
        
        this.userName = userName;
        this.delegateUserName = null;
        
        this.userIpAddress = userIpAddress;
        this.startTime = currentTime();
    }

    public Session() {

    }

    public int getId() {
    	return prettyId;
    }
    
    public boolean allowDelegation() {
        return allowDelegation;
    }

    public void setDelegate(String delegateUserName) {
        if (!allowDelegation) {
            throw new IllegalAccessError("Not allowed to delegate");
        }
        this.delegateUserName = delegateUserName;
    }

    public String getUserName() {
        if (allowDelegation && delegateUserName != null) {
            return delegateUserName;
        }
        else {
            return userName;
        }
    }
    
    public String getRealUserName() {
        return userName;
    }

    public String getUserIpAddress() {
        return userIpAddress;
    }

	public long getStartTime() {
		return startTime;
	}

	private static long currentTime() {
        return System.currentTimeMillis();
    }

    @Override
	public boolean equals(Object o) {
        if (o == null || !(o instanceof Session)) {
            return false;
        }
        Session other = (Session) o;
        return id.equals(other.id) && userName.equals(other.userName) && allowDelegation == other.allowDelegation;
    }

    @Override
	public int hashCode() {
        return id.hashCode();
    }
    
    @Override
	public String toString() {
        return "Session(id=" + prettyId + ", user=" + userName + ")";
    }
}