/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server;

import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;

import edu.stanford.smi.protege.server.socket.RmiSocketFactory;
import edu.stanford.smi.protege.server.socket.SSLFactory;
import edu.stanford.smi.protege.server.socket.SSLFactory.Context;

public class SimpleStream implements RemoteSimpleStream {
    private final int bufferSize = 1024 * 1024;
    private InputStream is;
    private URL url;
    
    public SimpleStream(URL url) throws RemoteException {
        this.url = url;
        try {
            is = url.openStream();
        }
        catch (IOException ioe) {
            throw new RemoteException("Could not open remote file " + url, ioe);
        }
        UnicastRemoteObject.exportObject(this, 
                                         SSLFactory.getServerPort(Context.ALWAYS),
                                         new RmiSocketFactory(SSLFactory.Context.ALWAYS),
                                         new RmiSocketFactory(SSLFactory.Context.ALWAYS));
    }
    
    public byte[] read() throws RemoteException {
        try {
            byte[] buffer = new byte[bufferSize];
            int len = is.read(buffer);
            if (len > 0) {
                byte[] output = new byte[len];
                System.arraycopy(buffer, 0, output, 0, len);
                return output;
            }
            else {
                return null;
            }
        }
        catch (IOException ioe) {
            throw new RemoteException("IO Exception reading remote file " + url, ioe);
        }
    }
    
    public void close() throws RemoteException {
        try {
            is.close();
            is = null;
        }
        catch (IOException ioe) {
            throw new RemoteException("IO Exception closing remote file for " + url, ioe);
        }
    }

}
