/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server.metaproject;

import java.util.Collection;
import java.util.Set;

import edu.stanford.smi.protege.model.Instance;

public interface PolicyControlledObject {

    String getName();

    void setName(String name);


    String getDescription();

    void setDescription(String description);


    boolean isPolicyModifiableByClient();

    void setPolicyModifiableByClient(boolean modifiable);


    Instance getProtegeInstance();

    MetaProject getMetaProject();

    /*
     * Allowed group operation methods
     */

    Set<GroupOperation> getAllowedGroupOperations();

    void setAllowedGroupOperations(Collection<GroupOperation> groupOperations);

    void addAllowedGroupOperations(GroupOperation groupOperation);

    /*
     * Name - value property methods
     */

    Collection<PropertyValue> getPropertyValues();

    Collection<String> getPropertyValuesAsString(String prop);

    String getPropertyValue(String prop);

    void setPropertyValues(Collection<PropertyValue> propertyValues);

    void addPropertyValue(PropertyValue propertyValue);

    void addPropertyValue(String prop, String value);

    void removePropertyValue(PropertyValue propertyValue);

    void removePropertyValue(String prop, String value);

    /*
     * inCollection methods
     */

    Set<PolicyControlledObjectCollection> getInCollection();

    void addInCollection(PolicyControlledObjectCollection collection);

    void removeInCollection(PolicyControlledObjectCollection collection);

    void setInCollection(Set<PolicyControlledObjectCollection> collections);

}
