/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.server.socket;

import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;

public class TeeOutputStream extends OutputStream {
    public static String TEE_OUTPUT_OPTION="edu.stanford.bmir.protege.server.tee.output";
    private OutputStream os;
    private OutputStream fileOutput;
    private static int counter = 0;
    
    public TeeOutputStream(OutputStream os) throws FileNotFoundException {
        this.os = os;
        String fileName = System.getProperty(TEE_OUTPUT_OPTION);
        synchronized (TeeOutputStream.class) {
            fileName = fileName + "-" + (counter++) + ".iostream";
        }
        File f = new File(fileName);
        fileOutput = new BufferedOutputStream(new FileOutputStream(f));
    }
    
    @Override
    public void write(int b) throws IOException {
        fileOutput.write(b);
        os.write(b);
    }
    
    @Override
    public void write(byte[] b, int off, int len) throws IOException {
        fileOutput.write(b, off, len);
        os.write(b, off, len);
    }
    
    @Override
    public void flush() throws IOException {
        fileOutput.flush();
        os.flush();
    }
    
    @Override
    public void close() throws IOException {
        fileOutput.flush();
        fileOutput.close();
        os.close();
    }

    
    
}
