/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.ui;

import java.awt.*;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.model.Frame;

/**
 * Frame Renderer that makes it clear whether the frame being rendered is valid or not.  Invalid frames are rendered in
 * red.
 *
 * @author    Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class OwnSlotValueFrameRenderer extends FrameRenderer {
    private static final long serialVersionUID = 7172693591093061328L;
    private static final Color INVALID_ITEM_COLOR = Color.red;
    private final Frame _frame;
    private final Slot _slot;

    public OwnSlotValueFrameRenderer(Frame frame, Slot slot) {
        _frame = frame;
        _slot = slot;
    }

    public void load(Object o) {
        super.load(o);
        if (!_frame.isValidOwnSlotValue(_slot, o)) {
            setForegroundColorOverride(INVALID_ITEM_COLOR);
        }
    }
}
