/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.ui;

import javax.swing.*;

import edu.stanford.smi.protege.action.*;
import edu.stanford.smi.protege.util.*;

/**
 * The main toolbar for the application.
 * 
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class ProjectToolBar extends JToolBar {

    private static final long serialVersionUID = -252712597962765189L;

    public void updateUI() {
        super.updateUI();
        setOpaque(false);
        setRollover(true);
        setFloatable(false);
        setBorderPainted(false);
        setBorder(BorderFactory.createEmptyBorder(2, 2, 0, 0));
        setAlignmentX(0.5f);
    }

    public ProjectToolBar() {
        addButton(new CreateProject(true));
        addButton(new OpenProject(true));
        addButton(new SaveProject(true));
        addSeparator();

        addButton(new Cut(true));
        addButton(new Copy(true));
        addButton(new Paste(true));
        addButton(new Clear(true));
        addSeparator();

        addButton(new ArchiveProject(true));
        addButton(new RevertProject(true));
        addSeparator();

        addButton(new UndoAction(true));
        addButton(new RedoAction(true));
        addSeparator();
        /*
         * addButton(new DefaultAction("Find", Icons.getFindIcon())); addButton(new DefaultAction("Find Previous",
         * Icons.getFindPreviousIcon())); addButton(new DefaultAction("Find Next", Icons.getFindNextIcon()));
         * addSeparator();
         */
        // addButton(new CascadeWindows(true));
        // addButton(new CloseAllWindows(true));
    }

    public void addButton(Action action) {
        JButton button = ComponentFactory.addLargeToolBarButton(this, action);
        button.setFocusable(false);
    }

    public void addToggleButton(Action action) {
        ComponentFactory.addLargeToggleToolBarButton(this, action);
    }

    public String toString() {
        return StringUtilities.getClassName(this);
    }
}