/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.ui;

import java.awt.*;

import javax.swing.*;
import javax.swing.border.*;

import edu.stanford.smi.protege.resource.*;
import edu.stanford.smi.protege.util.*;

/**
 * A window for the application startup splash screen. This just displays the nerd icon and the version number.
 * 
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class SplashScreen extends JWindow {
    private static final long serialVersionUID = 4752946291493511390L;
    private WaitCursor _waitCursor;

    public SplashScreen() {
        _waitCursor = new WaitCursor(this);
        String labelText = "Loading " + Text.getProgramNameAndVersion();
        // setTitle("Loading " + Text.getProgramName());
        // setIconImage(Icons.getNerd16x16Image());

        JLabel label = ComponentFactory.createLabel(labelText, SwingConstants.CENTER);

        JLabel icon = ComponentFactory.createLabel(Icons.getLogoSplashIcon());

        getContentPane().setLayout(new BorderLayout());
        JPanel panel = new JPanel(new BorderLayout());
        panel.add(icon, BorderLayout.CENTER);
        panel.add(label, BorderLayout.SOUTH);
        panel.setBorder(BorderFactory.createEtchedBorder(EtchedBorder.LOWERED));
        getContentPane().add(panel);
        pack();
        ComponentUtilities.center(this);
        setVisible(true);
        Toolkit.getDefaultToolkit().sync();
    }

    public void dispose() {
        setVisible(false);

        super.dispose();
        _waitCursor.hide();

        getContentPane().removeAll();
        getContentPane().setLayout(null);
    }

}