/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util;

import edu.stanford.smi.protege.ui.ProjectView;
import edu.stanford.smi.protege.widget.Widget;

public class ProjectViewEvent extends AbstractEvent {
	private static final long serialVersionUID = -7883249925606924610L;


    public enum Type {
		addTab, removeTab, save, close;
		
		static Type typeFromOrdinal(int ordinal) {
			for (Type t : Type.values()) {
				if (t.ordinal() == ordinal) {
					return t;
				}
			}
			return null;
		}
	};
	
	private ProjectView projectView;
	private Type type;
	private Widget widget;
	
	public ProjectViewEvent(ProjectView projectView, Type type) {
		super(projectView, type.ordinal());
		this.projectView = projectView;
		this.type = type;
	}
	
	/**
	 * @return Returns the projectView.
	 */
	public ProjectView getProjectView() {
		return projectView;
	}
	/**
	 * @return Returns the type.
	 */
	public Type getType() {
		return type;
	}

	public void setWidget(Widget widget) {
		if (type != Type.addTab) {
			throw new UnsupportedOperationException("Adding a widget to a " + type + " event?");
		}
		this.widget = widget;
	}
	
	
	public Widget getWidget() {
	  return widget;
	}
}
