/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util;

//ESCA*JAVA0130

import java.awt.event.*;
import java.util.*;

import javax.swing.*;

import edu.stanford.smi.protege.resource.*;

/**
 * An action for the standard view button that appears on many slot widgets.  Typically this action causes a form
 * to pop up for the selected frame.  The actually implementation though is delegated to a template method.
 *
 * @author    Ray Fergerson <fergerson@smi.stanford.edu>
 */
public abstract class ViewAction extends AllowableAction {

    private static final long serialVersionUID = 2185080283598996673L;

    protected ViewAction(ResourceKey key, Selectable selectable) {
        super(key, selectable);
    }

    protected ViewAction(Selectable selectable) {
        super(ResourceKey.VALUE_VIEW, selectable);
    }

    protected ViewAction(String text, Selectable selectable) {
        super(text, Icons.getViewIcon(), selectable);
    }

    protected ViewAction(String text, Selectable selectable, Icon icon) {
        super(text, text, icon, selectable);
    }

    public void actionPerformed(ActionEvent event) {
        if (isAllowed()) {
            WaitCursor cursor = new WaitCursor((JComponent) getSelectable());
            try {
                onView();
            } finally {
                cursor.hide();
            }
        }
    }

    public void onView() {
        Iterator i = getSelection().iterator();
        while (i.hasNext()) {
            onView(i.next());
        }
    }

    public void onView(Object o) {
        Log.getLogger().warning("onView called: should have been overridden");
    }
}
