/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util.transaction.cache;

import edu.stanford.smi.protege.model.KnowledgeBase;
import edu.stanford.smi.protege.util.transaction.TransactionIsolationLevel;
import edu.stanford.smi.protege.util.transaction.TransactionMonitor;
import edu.stanford.smi.protege.util.transaction.cache.impl.BasicCache;
import edu.stanford.smi.protege.util.transaction.cache.impl.CompleteableCache;
import edu.stanford.smi.protege.util.transaction.cache.impl.InvalidatableCache;
import edu.stanford.smi.protege.util.transaction.cache.impl.ReadCommittedCache;
import edu.stanford.smi.protege.util.transaction.cache.impl.ReadUncommittedCache;
import edu.stanford.smi.protege.util.transaction.cache.impl.RepeatableReadCache;

public class CacheFactory {
    
    public static <S, V, R> Cache<S, V, R> createEmptyCache(KnowledgeBase kb) {
        TransactionMonitor tsm = kb.getFrameStoreManager().getHeadFrameStore().getTransactionStatusMonitor();
        TransactionIsolationLevel level;
        if (tsm == null) {
            level = TransactionIsolationLevel.READ_UNCOMMITTED;
        }
        else {
            level = tsm.getTransationIsolationLevel();
        }
        return createEmptyCache(level);
    }
    
    public static <S, V, R> Cache<S, V, R> createEmptyCache(TransactionIsolationLevel level) {
        Cache<S, V, R> untransactedCache = new CompleteableCache<S, V, R>(new BasicCache<S, V, R>());
        if (level == TransactionIsolationLevel.NONE) {
            return new InvalidatableCache<S, V, R>(untransactedCache, true);
        }
        if (level.compareTo(TransactionIsolationLevel.READ_UNCOMMITTED) <= 0) {
            return new InvalidatableCache<S, V, R>(new ReadUncommittedCache<S, V, R>(untransactedCache), true);
        }
        Cache<S, V, R> readCommittedCache = new ReadCommittedCache<S, V, R>(untransactedCache);
        if (level == TransactionIsolationLevel.READ_COMMITTED) {
            return new InvalidatableCache<S, V, R>(readCommittedCache, false);
        }
        else {
            RepeatableReadCache<S, V, R> repeatableReadCache = new RepeatableReadCache<S, V, R>(readCommittedCache);
            return new InvalidatableCache<S, V, R>(repeatableReadCache, false);
        }
    }

}
