/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.util.transaction.cache.serialize;

import edu.stanford.smi.protege.util.transaction.cache.Cache;
import edu.stanford.smi.protege.util.transaction.cache.CacheResult;

public class CacheRead<S, V, R> extends SerializedCacheUpdate<S, V, R> {
	private static final long serialVersionUID = -1535032893706670178L;
    private V var;
	private CacheResult<R> value;
	
	public CacheRead(S session, V var, CacheResult<R> value) {
	    super(session);
	    this.var = var;
	    this.value = value;
	}
	
	public V getVar() {
		return var;
	}
	public CacheResult<R> getValue() {
		return value;
	}
	
	@Override
	public void performUpdate(Cache<S, V, R> cache) {
	    if (value.isValid()) {
	        cache.updateCache(getSession(), var, value.getResult());
	    }
	    else {
	    	cache.updateCache(getSession(), var);
	    }
	}
	
	public String toString() {
		StringBuffer sb = new StringBuffer("<CacheOp: Session ");
		sb.append(getSession());
		sb.append(" reads var ");
		sb.append(getVar());
		sb.append(" retrieving ");
		sb.append(getValue());
		sb.append(">");
		return sb.toString();
	}
	
}
