/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.widget;

import edu.stanford.smi.protege.event.*;
import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.util.*;

/**
 * Base class for all ClsWidgets.  For the moment all of the implementation for this is in _AbstractWidget.
 * 
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */

public abstract class AbstractClsWidget extends AbstractWidget implements ClsWidget {
    private static final long serialVersionUID = -3827881889241261768L;
    private Cls _cls;
    private Cls _associatedCls;
    private Instance _instance;
    private ListenerCollection _widgetListeners = new ListenerList(new WidgetEventDispatcher());

    private FrameListener _instanceListener = new FrameAdapter() {
        public void ownSlotValueChanged(FrameEvent event) {
            handleOwnSlotValueChanged(event.getSlot());
        }
        public void browserTextChanged(FrameEvent event) {
            handleBrowserTextChanged();
        }
    };

    public void dispose() {
        if (_instance != null) {
            _instance.removeFrameListener(_instanceListener);
        }
    }

    public Instance getInstance() {
        return _instance;
    }
    public void postWidgetEvent(int type) {
        _widgetListeners.postEvent(this, type);
    }
    public void addWidgetListener(WidgetListener listener) {
        _widgetListeners.add(this, listener);
    }
    public void removeWidgetListener(WidgetListener listener) {
        _widgetListeners.remove(this, listener);
    }

    public void setup(WidgetDescriptor d, boolean isDesignTime, Project p, Cls cls) {
        super.setup(d, isDesignTime, p);
        _cls = cls;
    }
    protected void handleBrowserTextChanged() {
        postWidgetEvent(WidgetEvent.LABEL_CHANGED);
    }

    protected void handleFrameNameChanged() {
        postWidgetEvent(WidgetEvent.LABEL_CHANGED);
    }

    public Cls getCls() {
        return _cls;
    }

    public Cls getAssociatedCls() {
        return _associatedCls;
    }

    public void setAssociatedCls(Cls cls) {
        _associatedCls = cls;
    }

    public void setInstance(Instance instance) {
        if (_instance != null) {
            _instance.removeFrameListener(_instanceListener);
        }
        _instance = instance;
        if (_instance != null) {
            _instance.addFrameListener(_instanceListener);
        }
    }

    protected void handleOwnSlotValueChanged(Slot slot) {
        AbstractSlotWidget widget = (AbstractSlotWidget) getSlotWidget(slot);
        if (widget != null) {
            widget.loadValues();
        }
    }
}
