/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.widget;

import java.awt.*;
import java.util.*;

import javax.swing.*;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.util.*;

/**
 * Base class for the "values" component that appears beneath the "type selection" combobox in the slots form.  This
 * widge is different (or absent) depending on the value selected in the combobox.
 * 
 * @author Ray Fergerson <fergerson@smi.stanford.edu>
 */
abstract class AbstractValuesComponent extends AbstractSelectableComponent implements ValuesComponent, Disposable {

    private static final long serialVersionUID = -4480165504667698341L;

    public AbstractValuesComponent() {
        setLayout(new BorderLayout());
    }

    public void dispose() {
    }

    public JComponent getComponent() {
        return this;
    }

    public KnowledgeBase getKnowledgeBase() {
        return getWidget().getKnowledgeBase();
    }

    public Collection getValues() {
        return null;
    }

    private SlotWidget getWidget() {
        return (SlotWidget) getParent();
    }

    protected Slot getSlotInstance() {
        return (Slot) getWidget().getInstance();
    }

    protected Cls getAssociatedCls() {
        return getWidget().getAssociatedCls();
    }

    public void setEditable(boolean b) {
        // do nothing
    }

    public void setValues(Collection values) {
    }

    public void valueChanged() {
        ((AbstractSlotWidget) getParent()).valueChanged();
    }

    protected boolean isOverride() {
        return getAssociatedCls() != null;
    }
}
