/*
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License");  you may not use this file except in 
 * compliance with the License.  You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 *
 * The Original Code is Protege-2000.
 *
 * The Initial Developer of the Original Code is Stanford University. Portions
 * created by Stanford University are Copyright (C) 2007.  All Rights Reserved.
 *
 * Protege was developed by Stanford Medical Informatics
 * (http://www.smi.stanford.edu) at the Stanford University School of Medicine
 * with support from the National Library of Medicine, the National Science
 * Foundation, and the Defense Advanced Research Projects Agency.  Current
 * information about Protege can be obtained at http://protege.stanford.edu.
 *
 */

package edu.stanford.smi.protege.widget;

import java.awt.*;
import java.util.*;

import edu.stanford.smi.protege.model.*;
import edu.stanford.smi.protege.util.*;

/**
 * A renderer for widget descriptors.  This just strips off the package information on the widget class file and 
 * displays the short class file name.  This is not really guaranteed to be unique and really isn't a great scheme 
 * anyway.  Much better would be to have another static method on the widget that specifies the browser text. 
 *
 * @author    Ray Fergerson <fergerson@smi.stanford.edu>
 */
public class WidgetDescriptorRenderer extends DefaultRenderer {
    private static final long serialVersionUID = 3251699554890095247L;
    private Project project;

    public WidgetDescriptorRenderer(Project project) {
        this.project = project;
    }

    public void load(Object o) {
        StringBuffer text = new StringBuffer();
        WidgetDescriptor d = (WidgetDescriptor) o;
        String longName = d.getWidgetClassName();
        if (longName == null) {
            text.append("<none>");
        } else {
            int index = longName.lastIndexOf('.');
            text.append(longName.substring(index + 1));
            Collection errors = new ArrayList();
            boolean isSuitable = WidgetUtilities.isSuitableTab(longName, project, errors);
            if (!isSuitable) {
                setFontStyle(Font.ITALIC);
                text.append(" -- ");
                Iterator i = errors.iterator();
                while (i.hasNext()) {
                    Object error = i.next();
                    text.append(error.toString());
                }
                // text.append(")");
            }
        }
        setMainText(text.toString());
    }
}
